@@ -14,7 +14,6 @@ use constant VALUE => "\x07YAML\x07VALUE\x07";
 
 # Common YAML character sets
 my $ESCAPE_CHAR = '[\\x00-\\x08\\x0b-\\x0d\\x0e-\\x1f]';
-my $FOLD_CHAR = '>';
 my $LIT_CHAR = '|';    
 
 #==============================================================================
@@ -81,8 +80,6 @@ sub _prewalk {
 
     # Handle regexps
     if (ref($_[0]) eq 'Regexp') {  
-        $self->transferred->{$node_id} =
-          YAML::Type::regexp->yaml_dump($_[0], $class, $self);
         return;
     }
 
@@ -210,7 +207,12 @@ sub _emit_node {
     my $self = shift;
     my ($type, $node_id);
     my $ref = ref($_[0]);
-    if ($ref and $ref ne 'Regexp') {
+    if ($ref) {
+        if ($ref eq 'Regexp') {
+            $self->_emit(' !!perl/regexp');
+            $self->_emit_str("$_[0]");
+            return;
+        }
         (undef, $type, $node_id) = $self->node_info($_[0], $self->stringify);
     }
     else {
@@ -230,7 +232,8 @@ sub _emit_node {
               $self->node_info($value, $self->stringify);
         }
         else {
-            $tag = ynode($self->transferred->{$node_id})->tag->short;
+            $ynode = ynode($self->transferred->{$node_id});
+            $tag = defined $ynode ? $ynode->tag->short : '';
             $type = 'SCALAR';
             (undef, undef, $node_id) = 
               $self->node_info(
@@ -436,18 +439,12 @@ sub _emit_str {
             $self->_emit_block($LIT_CHAR, $_[0]),
             $self->_emit($eb), last
               if $self->use_block;
-            $self->_emit($sb),
-            $self->_emit_block($FOLD_CHAR, $_[0]),
-            $self->_emit($eb), last
+              Carp::cluck "[YAML] \$UseFold is no longer supported"
               if $self->use_fold;
             $self->_emit($sf),
             $self->_emit_double($_[0]),
             $self->_emit($ef), last
               if length $_[0] <= 30;
-            $self->_emit($sb),
-            $self->_emit_block($FOLD_CHAR, $_[0]),
-            $self->_emit($eb), last
-              if $_[0] =~ /^\S[^\n]{76}/m;
             $self->_emit($sf),
             $self->_emit_double($_[0]),
             $self->_emit($ef), last
@@ -489,7 +486,6 @@ sub is_valid_plain {
     return 1;
 }
 
-# A nested scalar is either block or folded 
 sub _emit_block {
     my $self = shift;
     my ($indicator, $value) = @_;
@@ -499,10 +495,6 @@ sub _emit_block {
     $value = '~' if not defined $value;
     $self->{stream} .= $chomp;
     $self->{stream} .= $self->indent_width if $value =~ /^\s/;
-    if ($indicator eq $FOLD_CHAR) {
-        $value = $self->fold($value);
-        chop $value unless $chomp eq '+';
-    }
     $self->{stream} .= $self->indent($value);
 }
 
@@ -543,28 +535,6 @@ sub indent {
     return $text;
 }
 
-# Fold a paragraph to fit within a certain columnar restraint.
-sub fold {
-    my $self = shift;
-    my ($text) = @_;
-    my $folded = '';
-    $text =~ s/^(\S.*)\n(?=\S)/$1\n\n/gm;
-    while (length $text > 0) {
-        if ($text =~ s/^([^\n]{0,76})(\n|\Z)//) {
-            $folded .= $1;
-        }
-        elsif ($text =~ s/^(.{0,76})\s//) { 
-            $folded .= $1;
-        }
-        else {
-            $self->die("bad news") unless $text =~ s/(.*?)(\s|\Z)//;
-            $folded .= $1;
-        }
-        $folded .= "\n";
-    }
-    return $folded;
-}
-
 # Escapes for unprintable characters
 my @escapes = qw(\z   \x01 \x02 \x03 \x04 \x05 \x06 \a
                  \x08 \t   \n   \v   \f   \r   \x0e \x0f
